Learn R Programming

npregderiv (version 1.0)

wafer40: The data set on the \(n\)=7755 substrate's deflection measurements before and after the thin film deposition in two radial directions.

Description

The data frame on the deflection measurements is described and analyzed in the article of Savchuk and Volinsky (2020).

Usage

wafer40

Arguments

Format

The data frame has five variables:

x_dat

design points (separated by 0.000005 m);

y_before_0

deflections measurements (in m) before film deposition at 0 degrees;

y_after_0

deflections measurements (in m) after film deposition at 0 degrees;

y_before_90

deflections measurements (in m) before film deposition at 90 degrees;

y_after_90

deflections measurements (in m) after film deposition at 90 degrees.

See Also

reg_2derivWL.

Examples

Run this code
# NOT RUN {
# EXAMPLE: Plotting scatter plot of deflection in the case of 0 degrees before the film
# deposition. Note: position is displayed in mm, whereas the deflection is displayed in
# micrometers. No smoothing is used. The original n=7755 data points are plotted.
dev.new()
plot(wafer40$x_dat*1000,wafer40$y_before_0*1000000,pch=20,
     main="Deflection BEFORE film deposition. Angle: 0 degrees.",xlab="",ylab="",
     cex.axis=2,cex.main=2)
title(ylab=expression(paste("deflection, ", mu, "m")), xlab="position, mm",
      line=2.25, cex.lab=2)
# }

Run the code above in your browser using DataLab