# NOT RUN {
# EXAMPLE: Plotting scatter plot of deflection in the case of 0 degrees before the film
# deposition. Note: position is displayed in mm, whereas the deflection is displayed in
# micrometers. No smoothing is used. The original n=7755 data points are plotted.
dev.new()
plot(wafer40$x_dat*1000,wafer40$y_before_0*1000000,pch=20,
main="Deflection BEFORE film deposition. Angle: 0 degrees.",xlab="",ylab="",
cex.axis=2,cex.main=2)
title(ylab=expression(paste("deflection, ", mu, "m")), xlab="position, mm",
line=2.25, cex.lab=2)
# }
Run the code above in your browser using DataLab